==> flink-1.17.2-src.tgz: flink-1.17.2/flink-end-to-end-tests/flink-dataset-fine-grained-recovery-test/src/main/java/org/apache/flink/batch/tests/BlockingIncrementingMapFunction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.flink.batch.tests;

import org.apache.flink.api.common.functions.RichMapFunction;
import org.apache.flink.batch.tests.util.FileBasedOneShotLatch;
import org.apache.flink.configuration.Configuration;

import java.nio.file.Paths;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * A map function that increments values by one.
 *
 * <p>Processing of elements is held until a latch file is created.
 */
public class BlockingIncrementingMapFunction extends RichMapFunction<Long, Long> {

    private final String latchFilePath;

    private transient FileBasedOneShotLatch latch;

    public BlockingIncrementingMapFunction(final String latchFilePath) {
        this.latchFilePath = checkNotNull(latchFilePath);
    }

    @Override
    public void open(final Configuration parameters) {
        latch = new FileBasedOneShotLatch(Paths.get(latchFilePath));
    }

    @Override
    public void close() throws Exception {
        latch.close();
    }

    @Override
    public Long map(final Long value) throws InterruptedException {
        latch.await();
        return value + 1;
    }
}

==> flink-1.20.3-src.tgz: flink-1.20.3/flink-end-to-end-tests/flink-dataset-fine-grained-recovery-test/src/main/java/org/apache/flink/batch/tests/BlockingIncrementingMapFunction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.flink.batch.tests;

import org.apache.flink.api.common.functions.OpenContext;
import org.apache.flink.api.common.functions.RichMapFunction;
import org.apache.flink.batch.tests.util.FileBasedOneShotLatch;

import java.nio.file.Paths;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * A map function that increments values by one.
 *
 * <p>Processing of elements is held until a latch file is created.
 */
public class BlockingIncrementingMapFunction extends RichMapFunction<Long, Long> {

    private final String latchFilePath;

    private transient FileBasedOneShotLatch latch;

    public BlockingIncrementingMapFunction(final String latchFilePath) {
        this.latchFilePath = checkNotNull(latchFilePath);
    }

    @Override
    public void open(final OpenContext openContext) {
        latch = new FileBasedOneShotLatch(Paths.get(latchFilePath));
    }

    @Override
    public void close() throws Exception {
        latch.close();
    }

    @Override
    public Long map(final Long value) throws InterruptedException {
        latch.await();
        return value + 1;
    }
}
